summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/commands.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit7c71ab86d1f7e387fc3df63b48df07231f111862 (patch)
tree30ba2d2f840ff5fd458b6113e9c3f2e8a71d510d /kexi/formeditor/commands.cpp
parentafbfdc507bfaafc8824a9808311d57a9ece87510 (diff)
downloadkoffice-7c71ab86d1f7e387fc3df63b48df07231f111862.tar.gz
koffice-7c71ab86d1f7e387fc3df63b48df07231f111862.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/formeditor/commands.cpp')
-rw-r--r--kexi/formeditor/commands.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kexi/formeditor/commands.cpp b/kexi/formeditor/commands.cpp
index d628d53f..c08e44e6 100644
--- a/kexi/formeditor/commands.cpp
+++ b/kexi/formeditor/commands.cpp
@@ -236,7 +236,7 @@ AlignWidgetsCommand::execute()
int gridX = m_form->gridSize();
int gridY = m_form->gridSize();
- TQWidget *tqparentWidget = m_form->selectedWidgets()->first()->tqparentWidget();
+ TQWidget *parentWidget = m_form->selectedWidgets()->first()->parentWidget();
int tmpx, tmpy;
WidgetList list;
@@ -265,7 +265,7 @@ AlignWidgetsCommand::execute()
case AlignToLeft:
{
- tmpx = tqparentWidget->width();
+ tmpx = parentWidget->width();
for(TQWidget *w = list.first(); w; w = list.next())
{
if(w->x() < tmpx)
@@ -293,7 +293,7 @@ AlignWidgetsCommand::execute()
case AlignToTop:
{
- tmpy = tqparentWidget->height();
+ tmpy = parentWidget->height();
for(TQWidget *w = list.first(); w; w = list.next())
{
if(w->y() < tmpy)
@@ -378,11 +378,11 @@ AdjustSizeCommand::AdjustSizeCommand(int type, WidgetList &list, Form *form)
{
for(TQWidget *w = list.first(); w; w = list.next())
{
- if(w->tqparentWidget() && w->tqparentWidget()->isA(TQWIDGETSTACK_OBJECT_NAME_STRING))
+ if(w->parentWidget() && w->parentWidget()->isA(TQWIDGETSTACK_OBJECT_NAME_STRING))
{
- w = w->tqparentWidget(); // widget is WidgetStack page
- if(w->tqparentWidget() && w->tqparentWidget()->inherits(TQTABWIDGET_OBJECT_NAME_STRING)) // widget is tabwidget page
- w = w->tqparentWidget();
+ w = w->parentWidget(); // widget is WidgetStack page
+ if(w->parentWidget() && w->parentWidget()->inherits(TQTABWIDGET_OBJECT_NAME_STRING)) // widget is tabwidget page
+ w = w->parentWidget();
}
m_sizes.insert(w->name(), w->size());
@@ -446,8 +446,8 @@ AdjustSizeCommand::execute()
s.setWidth(30);
if(s.height() < 30)
s.setHeight(30);
- // small hack for flow tqlayouts
- int type = item->container() ? item->container()->tqlayoutType() : Container::NoLayout;
+ // small hack for flow layouts
+ int type = item->container() ? item->container()->layoutType() : Container::NoLayout;
if(type == Container::HFlow)
s.setWidth(s.width() + 5);
else if(type == Container::VFlow)
@@ -846,11 +846,11 @@ InsertWidgetCommand::debug()
/// CreateLayoutCommand ///////////////
-CreateLayoutCommand::CreateLayoutCommand(int tqlayoutType, WidgetList &list, Form *form)
- : m_form(form), m_type(tqlayoutType)
+CreateLayoutCommand::CreateLayoutCommand(int layoutType, WidgetList &list, Form *form)
+ : m_form(form), m_type(layoutType)
{
WidgetList *m_list=0;
- switch(tqlayoutType)
+ switch(layoutType)
{
case Container::HBox:
case Container::Grid:
@@ -890,7 +890,7 @@ CreateLayoutCommand::execute()
case Container::HSplitter: case Container::VSplitter:
classname = TQSPLITTER_OBJECT_NAME_STRING; break;
default:
- classname = Container::tqlayoutTypeToString(m_type).latin1();
+ classname = Container::layoutTypeToString(m_type).latin1();
}
if(m_name.isEmpty())// the name must be generated only once
@@ -1017,11 +1017,11 @@ BreakLayoutCommand::BreakLayoutCommand(Container *container)
m_containername = container->toplevel()->widget()->name();
m_name = container->widget()->name();
m_form = container->form();
- m_type = container->tqlayoutType();
+ m_type = container->layoutType();
for(ObjectTreeItem *tree = container->objectTree()->tqchildren()->first(); tree; tree = container->objectTree()->tqchildren()->next())
{
- TQRect r(container->widget()->mapTo(container->widget()->tqparentWidget(), tree->widget()->pos()), tree->widget()->size());
+ TQRect r(container->widget()->mapTo(container->widget()->parentWidget(), tree->widget()->pos()), tree->widget()->size());
m_pos.insert(tree->widget()->name(), r);
}
}
@@ -1385,7 +1385,7 @@ DeleteWidgetCommand::DeleteWidgetCommand(WidgetList &list, Form *form)
{
TQWidget *w = it.current();
// Don't delete tabwidget or widgetstack pages
- if(w->tqparentWidget()->inherits(TQWIDGETSTACK_OBJECT_NAME_STRING))
+ if(w->parentWidget()->inherits(TQWIDGETSTACK_OBJECT_NAME_STRING))
{
list.remove(w);
continue;
@@ -1399,8 +1399,8 @@ DeleteWidgetCommand::DeleteWidgetCommand(WidgetList &list, Form *form)
if (!item)
return;
- // We need to store both tqparentContainer and tqparentWidget as they may be different (eg for TabWidget page)
- m_containers.insert(item->name().latin1(), m_form->tqparentContainer(item->widget())->widget()->name());
+ // We need to store both parentContainer and parentWidget as they may be different (eg for TabWidget page)
+ m_containers.insert(item->name().latin1(), m_form->parentContainer(item->widget())->widget()->name());
m_parents.insert(item->name().latin1(), item->tqparent()->name().latin1());
FormIO::saveWidget(item, tqparent, m_domDoc);
form->connectionBuffer()->saveAllConnectionsForWidget(item->widget()->name(), m_domDoc);
@@ -1421,7 +1421,7 @@ DeleteWidgetCommand::execute()
if (!item || !item->widget())
continue;
- Container *cont = m_form->tqparentContainer(item->widget());
+ Container *cont = m_form->parentContainer(item->widget());
if (!containerToSelect)
containerToSelect = cont;
cont->deleteWidget(item->widget());
@@ -1476,7 +1476,7 @@ void
DeleteWidgetCommand::debug()
{
kdDebug() << "DeleteWidgetCommand: containers=" << m_containers.keys()
- << " tqparents=" << m_parents.keys() << " form=" << m_form->widget()->name() << endl;
+ << " parents=" << m_parents.keys() << " form=" << m_form->widget()->name() << endl;
}
// CutWidgetCommand
@@ -1510,7 +1510,7 @@ void
CutWidgetCommand::debug()
{
kdDebug() << "CutWidgetCommand: containers=" << m_containers.keys()
- << " tqparents=" << m_parents.keys() << " form=" << m_form->widget()->name()
+ << " parents=" << m_parents.keys() << " form=" << m_form->widget()->name()
<< " data=\"" << m_data.left(80) << "...\"" << endl;
}